# Synced from ballistica-master-server.
# EFRO_SYNC_HASH=73320357776312928298071216799147618513
#
"""Common components related to cloud hosted games."""

from __future__ import annotations

from enum import Enum
from dataclasses import dataclass
from typing import TYPE_CHECKING, Annotated

from efro.dataclassio import ioprepped, IOAttrs

if TYPE_CHECKING:
    pass


class HostedGameType(Enum):
    """Overall types of hosting we can do."""

    STRESS_TEST = 'stresstest'
    AD_HOC = 'adhoc'
    PRIVATE_PARTY = 'privparty'


class AdHocGameType(Enum):
    """Type of ad-hoc hosting we can do."""

    FFA = 'FFA'
    TEAMS = 'Teams'
    EON = 'EON'


@ioprepped
@dataclass
class HostedGameDef:
    """Defines a hosted game."""

    hosted_game_type: Annotated[HostedGameType, IOAttrs('tp')] = (
        HostedGameType.STRESS_TEST
    )

    # Stress-test fields:
    stress_test_minutes: Annotated[
        float, IOAttrs('stress_test_minutes', store_default=False)
    ] = 10.0

    # Ad-hoc fields:
    ad_hoc_name: Annotated[
        str | None, IOAttrs('ad_hoc_name', store_default=False)
    ] = None
    ad_hoc_minutes: Annotated[
        float | None, IOAttrs('ad_hoc_minutes', store_default=False)
    ] = None
    ad_hoc_minutes_unclean: Annotated[
        float, IOAttrs('ad_hoc_minutes_unclean', store_default=False)
    ] = 420.0
    ad_hoc_minutes_idle: Annotated[
        float, IOAttrs('ad_hoc_minutes_idle', store_default=False)
    ] = 30.0
    ad_hoc_game_type: Annotated[
        AdHocGameType | None, IOAttrs('ad_hoc_game_type', store_default=False)
    ] = None
    ad_hoc_game_public: Annotated[
        bool, IOAttrs('ad_hoc_game_public', store_default=False)
    ] = True

    # Private-Hosting fields:
    private_hosting_config: Annotated[
        str | None, IOAttrs('private_hosting_config', store_default=False)
    ] = None
    private_hosting_test_mode: Annotated[
        bool, IOAttrs('private_hosting_test_mode', store_default=False)
    ] = False
    private_hosting_account: Annotated[
        str | None, IOAttrs('private_hosting_account', store_default=False)
    ] = None
    private_hosting_code: Annotated[
        str | None, IOAttrs('private_hosting_code', store_default=False)
    ] = None
    private_hosting_party_name: Annotated[
        str | None, IOAttrs('private_hosting_party_name', store_default=False)
    ] = None

    # Universal load reserved for this task.
    load: Annotated[float, IOAttrs('load_scale', store_default=False)] = 1.0
