# Synced from ballistica-master-server.
# EFRO_SYNC_HASH=165059505679142447374497692103417284209
#
"""Common components related to cloud hosted games."""

from __future__ import annotations

from typing import TYPE_CHECKING


if TYPE_CHECKING:
    import datetime

    from redis import Redis


class DistributedCounter:
    """A distributed counter for things like counting in-flight tasks.

    Individual ids can be added and removed from the list and will also
    expire after some amount of time in case they are not removed. Then
    the total number of ids in the list can be efficiently queried.
    """

    def __init__(
        self,
        redis: Redis,
        expire: datetime.timedelta,
        update_period: datetime.timedelta,
    ) -> None:
        self.redis = redis
        self.expire = expire
        self.update_period = update_period

    def add(self, itemid: str) -> None:
        """Add an id to the counter."""

    def remove(self, itemid: str) -> None:
        """Remove an item from the counter."""

    def get_count(self) -> int:
        """Get the current item count."""
        return 0


class DistributedRateCounter:
    """A distributed counter for tracking a continuous rate."""

    def __init__(
        self,
        redis: Redis,
        period: datetime.timedelta,
        update_period: datetime.timedelta,
    ) -> None:
        self.redis = redis
        self.period = period
        self.update_period = update_period

    def register_event(self) -> None:
        """Register an event."""

    def get_rate(self) -> float:
        """Get the recent average number of events per period."""
        return 0.0
