"""Functionality specific to the servernode process."""


def main() -> None:
    """Main entry point."""
    import sys

    # Explicitly pull in env modules to init them very first thing since
    # they may set up logging or other implicitly global stuff.
    assert 'basn.env' not in sys.modules
    import basn.env

    assert 'basn.env' in sys.modules

    import asyncio
    import logging

    config_path = sys.argv[1]

    # We expect to be creating our own asyncio event loop.
    try:
        asyncio.get_running_loop()
        logging.error(
            'Found running asyncio loop; expected to be creating one.'
        )
    except Exception:
        pass
    loop = asyncio.new_event_loop()
    if basn.env.ASYNCIO_DEBUG:
        loop.set_debug(True)
    asyncio.set_event_loop(loop)

    # And now for the last, most important part of env:
    from basn.app import App

    app = basn.env.app = App(config_path)
    app.postinit()
    app.run()


if __name__ == '__main__':
    main()
